@@ -28,19 +28,24 @@
 #include <QTranslator>
 #include <QLocale>
 
+#if QT_VERSION < 0x040300
+#define lighter(x)	light(x)
+#define darker(x)	dark(x)
+#endif
 
-#if defined(Q_WS_X11)
 
 //-------------------------------------------------------------------------
-// Single application instance stuff (Qt/X11 only atm.)
+// Singleton application instance stuff (Qt/X11 only atm.)
 //
 
+#if defined(Q_WS_X11)
+
 #include <QX11Info>
 
 #include <X11/Xatom.h>
 #include <X11/Xlib.h>
 
-#define QJACKCTL_XUNIQUE "qjackctlMainForm_xunique"
+#define QJACKCTL_XUNIQUE "qjackctlApplication"
 
 #endif
 
@@ -94,7 +99,13 @@ public:
 		}
 	#if defined(Q_WS_X11)
 		m_pDisplay = QX11Info::display();
-		m_aUnique  = XInternAtom(m_pDisplay, QJACKCTL_XUNIQUE, false);
+		QString sUnique = QJACKCTL_XUNIQUE;
+		const char *pszServerName = ::getenv("JACK_DEFAULT_SERVER");
+		if (pszServerName) {
+			sUnique += '_';
+			sUnique += pszServerName;
+		}
+		m_aUnique = XInternAtom(m_pDisplay, sUnique.toUtf8().constData(), false);
 		XGrabServer(m_pDisplay);
 		m_wOwner = XGetSelectionOwner(m_pDisplay, m_aUnique);
 		XUngrabServer(m_pDisplay);
@@ -263,6 +274,28 @@ int main ( int argc, char **argv )
 		return 2;
 	}
 
+	// Dark themes grayed/disabled color group fix...
+	QPalette pal(app.palette());
+	if (pal.base().color().value() < 0x7f) {
+		pal.setColorGroup(QPalette::Disabled,
+			pal.windowText().color().darker(),
+			pal.button(),
+			pal.light(),
+			pal.dark(),
+			pal.mid(),
+			pal.text().color().darker(),
+			pal.text().color().lighter(),
+			pal.base(),
+			pal.window());
+		app.setPalette(pal);
+	}
+
+	// Set default base font...
+	int iBaseFontSize = app.font().pointSize();
+	if (settings.iBaseFontSize > 0)
+		iBaseFontSize = settings.iBaseFontSize;
+	app.setFont(QFont(app.font().family(), iBaseFontSize));
+
 	// What style do we create these forms?
 	Qt::WindowFlags wflags = Qt::Window
 #if QT_VERSION >= 0x040200
