@@ -1,7 +1,7 @@
 // qjackctlConnect.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2008, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -203,8 +203,10 @@ void qjackctlPortItem::setHilite ( bool bHilite )
 	}
 
 	// Set the new color.
-	QTreeWidgetItem::setTextColor(0, m_bHilite ? Qt::blue
-		: QTreeWidgetItem::treeWidget()->palette().text().color());
+	const QPalette& pal = QTreeWidgetItem::treeWidget()->palette();
+	QTreeWidgetItem::setTextColor(0, m_bHilite
+		? (pal.base().color().value() < 0x7f ? Qt::cyan : Qt::blue)
+		: pal.text().color());
 }
 
 
@@ -362,8 +364,10 @@ void qjackctlClientItem::setHilite ( bool bHilite )
 		m_iHilite--;
 
 	// Set the new color.
-	QTreeWidgetItem::setTextColor(0, m_iHilite > 0 ? Qt::darkBlue
-		: QTreeWidgetItem::treeWidget()->palette().text().color());
+	const QPalette& pal = QTreeWidgetItem::treeWidget()->palette();
+	QTreeWidgetItem::setTextColor(0, m_iHilite > 0
+		? (pal.base().color().value() < 0x7f ? Qt::darkCyan : Qt::darkBlue)
+		: pal.text().color());
 }
 
 
@@ -1105,6 +1109,10 @@ void qjackctlConnectorView::paintEvent ( QPaintEvent * )
 	int x2, y2, h2;
 	int i, rgb[3] = { 0x33, 0x66, 0x99 };
 
+	// Inline adaptive to draker background themes...
+	if (QWidget::palette().window().color().value() < 0x7f)
+		for (i = 0; i < 3; ++i) rgb[i] += 0x33;
+
 	// Initialize color changer.
 	i = 0;
 	// Almost constants.
