@@ -407,6 +407,7 @@ bool qjackctlMainForm::setup ( qjackctlSetup *pSetup )
 	updateMessagesLimit();
 	updateConnectionsFont();
 	updateConnectionsIconSize();
+	updateJackClientPortAlias();
 	updateBezierLines();
 	updateActivePatchbay();
 	updateSystemTray();
@@ -1287,6 +1288,18 @@ void qjackctlMainForm::updateConnectionsIconSize (void)
 }
 
 
+// Update of JACK client/port alias display mode.
+void qjackctlMainForm::updateJackClientPortAlias (void)
+{
+	if (m_pSetup == NULL)
+		return;
+
+	qjackctlJackClientList::setJackClientPortAlias(m_pSetup->iJackClientPortAlias);
+
+	refreshJackConnections();
+}
+
+
 // Update the connection and patchbay line style.
 void qjackctlMainForm::updateBezierLines (void)
 {
@@ -2352,6 +2365,7 @@ void qjackctlMainForm::showSetupForm (void)
 		QString sOldDisplayFont2        = m_pSetup->sDisplayFont2;
 		QString sOldConnectionsFont     = m_pSetup->sConnectionsFont;
 		int     iOldConnectionsIconSize = m_pSetup->iConnectionsIconSize;
+		int     iOldJackClientPortAlias = m_pSetup->iJackClientPortAlias;
 		int     iOldTimeDisplay         = m_pSetup->iTimeDisplay;
 		int     iOldTimeFormat          = m_pSetup->iTimeFormat;
 		bool    bOldDisplayEffect       = m_pSetup->bDisplayEffect;
@@ -2371,6 +2385,7 @@ void qjackctlMainForm::showSetupForm (void)
 		bool    bOldRightButtons        = m_pSetup->bRightButtons;
 		bool    bOldTransportButtons    = m_pSetup->bTransportButtons;
 		bool    bOldTextLabels          = m_pSetup->bTextLabels;
+		int     iOldBaseFontSize        = m_pSetup->iBaseFontSize;
 		// Load the current setup settings.
 		pSetupForm->setup(m_pSetup);
 		// Show the setup dialog...
@@ -2387,6 +2402,8 @@ void qjackctlMainForm::showSetupForm (void)
 			if (( bOldDisplayEffect && !m_pSetup->bDisplayEffect) ||
 				(!bOldDisplayEffect &&  m_pSetup->bDisplayEffect))
 				updateDisplayEffect();
+			if (iOldJackClientPortAlias != m_pSetup->iJackClientPortAlias)
+				updateJackClientPortAlias();
 			if (iOldConnectionsIconSize != m_pSetup->iConnectionsIconSize)
 				updateConnectionsIconSize();
 			if (sOldConnectionsFont != m_pSetup->sConnectionsFont)
@@ -2432,7 +2449,8 @@ void qjackctlMainForm::showSetupForm (void)
 				( bOldDelayedSetup   && !m_pSetup->bDelayedSetup)   ||
 				(!bOldDelayedSetup   &&  m_pSetup->bDelayedSetup)   ||
 				( bOldAlsaSeqEnabled && !m_pSetup->bAlsaSeqEnabled) ||
-				(!bOldAlsaSeqEnabled &&  m_pSetup->bAlsaSeqEnabled))
+				(!bOldAlsaSeqEnabled &&  m_pSetup->bAlsaSeqEnabled) ||
+				(iOldBaseFontSize    !=  m_pSetup->iBaseFontSize))
 				showDirtySetupWarning();
 			// If server is currently running, warn user...
 			showDirtySettingsWarning();
