@@ -1,7 +1,7 @@
 // qjackctlPatchbay.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2008, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -43,9 +43,6 @@
 // External patchbay loader.
 #include "qjackctlPatchbayFile.h"
 
-// Aliases accessors.
-#include "qjackctlConnectAlias.h"
-
 
 //----------------------------------------------------------------------
 // class qjackctlPlugItem -- Socket plug list item.
@@ -366,12 +363,14 @@ qjackctlSocketList::~qjackctlSocketList (void)
 
 
 // Client finder.
-qjackctlSocketItem *qjackctlSocketList::findSocket ( const QString& sSocketName )
+qjackctlSocketItem *qjackctlSocketList::findSocket (
+	const QString& sSocketName, int iSocketType )
 {
 	QListIterator<qjackctlSocketItem *> iter(m_sockets);
 	while (iter.hasNext()) {
 		qjackctlSocketItem *pSocket = iter.next();
-		if (sSocketName == pSocket->socketName())
+		if (sSocketName == pSocket->socketName() &&
+			iSocketType == pSocket->socketType())
 			return pSocket;
 	}
 
@@ -461,140 +460,6 @@ QPixmap *qjackctlSocketList::createPixmapMerge (
 }
 
 
-// JACK specific client:port connections snapshot.
-void qjackctlSocketList::clientJackSnapshot ( int iSocketType )
-{
-	// Grab JACK client:ports...
-	if (m_pJackClient == NULL)
-		return;
-
-	const char *pszJackPortType = JACK_DEFAULT_AUDIO_TYPE;
-#ifdef CONFIG_JACK_MIDI
-	if (iSocketType == QJACKCTL_SOCKETTYPE_JACK_MIDI)
-		pszJackPortType = JACK_DEFAULT_MIDI_TYPE;
-#endif
-
-	const char **ppszClientPorts = jack_get_ports(m_pJackClient,
-		NULL, pszJackPortType,
-		(m_bReadable ? JackPortIsOutput : JackPortIsInput));
-	if (ppszClientPorts) {
-		int iClientPort = 0;
-		while (ppszClientPorts[iClientPort]) {
-			QString sClientPort = ppszClientPorts[iClientPort];
-			qjackctlSocketItem *pSocket = NULL;
-			qjackctlPlugItem   *pPlug   = NULL;
-			int iColon = sClientPort.indexOf(':');
-			if (iColon >= 0) {
-				QString sClientName = sClientPort.left(iColon);
-				QString sPortName = qjackctlClientAlias::escapeRegExpDigits(
-					sClientPort.right(sClientPort.length() - iColon - 1));
-				pSocket = findSocket(sClientName);
-				if (pSocket)
-					pPlug = pSocket->findPlug(sPortName);
-				if (pSocket == NULL) {
-					int iSocketCount = listView()->topLevelItemCount();
-					if (iSocketCount > 0) {
-						pSocket = static_cast<qjackctlSocketItem *> (
-							listView()->topLevelItem(iSocketCount - 1));
-					}
-					pSocket = new qjackctlSocketItem(this, sClientName,
-						qjackctlClientAlias::escapeRegExpDigits(sClientName),
-						iSocketType, pSocket);
-				}
-				if (pSocket && pPlug == NULL) {
-					int iPlugCount = pSocket->childCount();
-					if (iPlugCount > 0) {
-						pPlug = static_cast<qjackctlPlugItem *> (
-							pSocket->child(iPlugCount - 1));
-					}
-					pPlug = new qjackctlPlugItem(pSocket, sPortName, pPlug);
-				}
-			}
-			iClientPort++;
-		}
-		::free(ppszClientPorts);
-	}
-}
-
-// ALSA specific client:port connections snapshot.
-void qjackctlSocketList::clientAlsaSnapshot ( int iSocketType )
-{
-	if (m_pAlsaSeq == NULL)
-		return;
-
-#ifdef CONFIG_ALSA_SEQ
-
-	// Grab ALSA subscribers...
-	snd_seq_client_info_t *pClientInfo;
-	snd_seq_port_info_t   *pPortInfo;
-	unsigned int uiAlsaFlags;
-	if (m_bReadable)
-		uiAlsaFlags = SND_SEQ_PORT_CAP_READ  | SND_SEQ_PORT_CAP_SUBS_READ;
-	else
-		uiAlsaFlags = SND_SEQ_PORT_CAP_WRITE | SND_SEQ_PORT_CAP_SUBS_WRITE;
-
-	snd_seq_client_info_alloca(&pClientInfo);
-	snd_seq_port_info_alloca(&pPortInfo);
-	snd_seq_client_info_set_client(pClientInfo, -1);
-	while (snd_seq_query_next_client(m_pAlsaSeq, pClientInfo) >= 0) {
-		int iAlsaClient = snd_seq_client_info_get_client(pClientInfo);
-		if (iAlsaClient > 0) {
-			QString sClientName = snd_seq_client_info_get_name(pClientInfo);
-			snd_seq_port_info_set_client(pPortInfo, iAlsaClient);
-			snd_seq_port_info_set_port(pPortInfo, -1);
-			while (snd_seq_query_next_port(m_pAlsaSeq, pPortInfo) >= 0) {
-				unsigned int uiPortCapability
-					= snd_seq_port_info_get_capability(pPortInfo);
-				if (((uiPortCapability & uiAlsaFlags) == uiAlsaFlags) &&
-					((uiPortCapability & SND_SEQ_PORT_CAP_NO_EXPORT) == 0)) {
-					QString sPortName = qjackctlClientAlias::escapeRegExpDigits(
-						snd_seq_port_info_get_name(pPortInfo));
-					qjackctlSocketItem *pSocket = NULL;
-					qjackctlPlugItem   *pPlug   = NULL;
-					pSocket = findSocket(sClientName);
-					if (pSocket)
-						pPlug = pSocket->findPlug(sPortName);
-					if (pSocket == NULL) {
-						int iSocketCount = listView()->topLevelItemCount();
-						if (iSocketCount > 0) {
-							pSocket = static_cast<qjackctlSocketItem *> (
-								listView()->topLevelItem(iSocketCount - 1));
-						}
-						pSocket = new qjackctlSocketItem(this, sClientName,
-							qjackctlClientAlias::escapeRegExpDigits(sClientName),
-							iSocketType, pSocket);
-					}
-					if (pSocket && pPlug == NULL) {
-						int iPlugCount = pSocket->childCount();
-						if (iPlugCount > 0) {
-							pPlug = static_cast<qjackctlPlugItem *> (
-								pSocket->child(iPlugCount - 1));
-						}
-						pPlug = new qjackctlPlugItem(pSocket, sPortName, pPlug);
-					}
-				}
-			}
-		}
-	}
-
-#endif	// CONFIG_ALSA_SEQ
-}
-
-
-// General client:port connections snapshot.
-void qjackctlSocketList::clientPortsSnapshot (void)
-{
-	clientJackSnapshot(QJACKCTL_SOCKETTYPE_JACK_AUDIO);
-
-#ifdef CONFIG_JACK_MIDI
-	clientJackSnapshot(QJACKCTL_SOCKETTYPE_JACK_MIDI);
-#endif
-#ifdef CONFIG_ALSA_SEQ
-	clientAlsaSnapshot(QJACKCTL_SOCKETTYPE_ALSA_MIDI);
-#endif
-}
-
-
 // Return currently selected socket item.
 qjackctlSocketItem *qjackctlSocketList::selectedSocketItem (void) const
 {
@@ -761,9 +626,10 @@ bool qjackctlSocketList::copySocketItem (void)
 		QString sSocketName;
 		QString sSkel = pSocketItem->socketName();
 		sSkel.remove(QRegExp("[0-9]+$")).append("%1");
+		int iSocketType = pSocketItem->socketType();
 		int iSocketNo = 1;
 		do { sSocketName = sSkel.arg(++iSocketNo); }
-		while (findSocket(sSocketName));
+		while (findSocket(sSocketName, iSocketType));
 		// Show up as a new socket...
 		socketForm.setWindowTitle(tr("%1 <Copy> - %2")
 			.arg(pSocketItem->socketName()).arg(m_sSocketCaption));
@@ -773,7 +639,7 @@ bool qjackctlSocketList::copySocketItem (void)
 		socketForm.setJackClient(m_pJackClient);
 		socketForm.setAlsaSeq(m_pAlsaSeq);
 		qjackctlPatchbaySocket socket(sSocketName,
-			pSocketItem->clientName(), pSocketItem->socketType());
+			pSocketItem->clientName(), iSocketType);
 		if (pSocketItem->isExclusive())
 			socket.setExclusive(true);
 		QListIterator<qjackctlPlugItem *> iter(pSocketItem->plugs());
@@ -1269,6 +1135,10 @@ void qjackctlPatchworkView::paintEvent ( QPaintEvent * )
 	int x2, y2, h2;
 	int i, rgb[3] = { 0x99, 0x66, 0x33 };
 
+	// Inline adaptive to darker background themes...
+	if (QWidget::palette().window().color().value() < 0x7f)
+		for (i = 0; i < 3; ++i) rgb[i] += 0x33;
+
 	// Initialize color changer.
 	i = 0;
 	// Almost constants.
@@ -1317,7 +1187,8 @@ void qjackctlPatchworkView::paintEvent ( QPaintEvent * )
 	while (iter.hasNext()) {
 		pISocket = iter.next();
 		qjackctlSocketItem *pISocketForward
-			= m_pPatchbayView->ISocketList()->findSocket(pISocket->forward());
+			= m_pPatchbayView->ISocketList()->findSocket(
+				pISocket->forward(), pISocket->socketType());
 		if (pISocketForward == NULL)
 			continue;
 		// Set new connector color.
@@ -1965,11 +1836,13 @@ void qjackctlPatchbay::loadRack ( qjackctlPatchbayRack *pPatchbayRack )
 	while (iter.hasNext()) {
 		qjackctlPatchbayCable *pCable = iter.next();
 		// Get proper sockets...
-		if (pCable->outputSocket() && pCable->inputSocket()) {
+		qjackctlPatchbaySocket *pOSocket = pCable->outputSocket();
+		qjackctlPatchbaySocket *pISocket = pCable->inputSocket();
+		if (pOSocket && pISocket) {
 			qjackctlSocketItem *pOSocketItem
-				= m_pOSocketList->findSocket((pCable->outputSocket())->name());
+				= m_pOSocketList->findSocket(pOSocket->name(), pOSocket->type());
 			qjackctlSocketItem *pISocketItem
-				= m_pISocketList->findSocket((pCable->inputSocket())->name());
+				= m_pISocketList->findSocket(pISocket->name(), pISocket->type());
 			if (pOSocketItem && pISocketItem)
 				connectSockets(pOSocketItem, pISocketItem);
 		}
@@ -2081,139 +1954,13 @@ snd_seq_t *qjackctlPatchbay::alsaSeq (void) const
 }
 
 
-// Audio connections snapshot.
-void qjackctlPatchbay::socketPlugJackSnapshot (
-	qjackctlSocketItem *pOSocket, qjackctlPlugItem *pOPlug )
-{
-	// Audio and MIDI engine descriptors...
-	jack_client_t *pJackClient = jackClient();
-
-	// Get current JACK port connections...
-	QString sOClientPort = pOSocket->socketName() + ':' + pOPlug->plugName();
-	const char **ppszIClientPorts = jack_port_get_all_connections(pJackClient,
-		jack_port_by_name(pJackClient, sOClientPort.toUtf8().constData()));
-	if (ppszIClientPorts) {
-		// Now, for each input client port...
-		int iIClientPort = 0;
-		while (ppszIClientPorts[iIClientPort]) {
-			QString sIClientPort = ppszIClientPorts[iIClientPort];
-			int iColon = sIClientPort.indexOf(':');
-			if (iColon >= 0) {
-				qjackctlSocketItem *pISocket = m_pISocketList->findSocket(
-					sIClientPort.left(iColon));
-				if (pISocket)
-					connectSockets(pOSocket, pISocket);
-			}
-			iIClientPort++;
-		}
-		::free(ppszIClientPorts);
-	}
-}
-
-
-// MIDI connections snapshot.
-void qjackctlPatchbay::socketPlugAlsaSnapshot (
-	qjackctlSocketItem *pOSocket, qjackctlPlugItem *pOPlug )
-{
-#ifdef CONFIG_ALSA_SEQ
-
-	// ALSA sequencer descriptors...
-	snd_seq_t *pAlsaSeq = alsaSeq();
-
-	// ALSA subscriber structures.
-	snd_seq_query_subscribe_t *pAlsaSubs;
-	snd_seq_addr_t seq_addr;
-	snd_seq_query_subscribe_alloca(&pAlsaSubs);
-
-	// ALSA readable (output) client ports...
-	snd_seq_client_info_t *pOClientInfo;
-	snd_seq_port_info_t   *pOPortInfo;
-	unsigned int uiOFlags = SND_SEQ_PORT_CAP_READ | SND_SEQ_PORT_CAP_SUBS_READ;
-
-	snd_seq_client_info_alloca(&pOClientInfo);
-	snd_seq_port_info_alloca(&pOPortInfo);
-
-	// ALSA sequencer writable (input) client ports...
-	snd_seq_client_info_t *pIClientInfo;
-	snd_seq_client_info_alloca(&pIClientInfo);
-
-	// Get current MIDI port connections...
-	snd_seq_client_info_set_client(pOClientInfo, -1);
-	while (snd_seq_query_next_client(pAlsaSeq, pOClientInfo) >= 0) {
-		int iOClient = snd_seq_client_info_get_client(pOClientInfo);
-		if (iOClient > 0) {
-			QString sOClientName = snd_seq_client_info_get_name(pOClientInfo);
-			if (sOClientName == pOSocket->clientName()) {
-				snd_seq_port_info_set_client(pOPortInfo, iOClient);
-				snd_seq_port_info_set_port(pOPortInfo, -1);
-				while (snd_seq_query_next_port(pAlsaSeq, pOPortInfo) >= 0) {
-					unsigned int uiOCapability
-						= snd_seq_port_info_get_capability(pOPortInfo);
-					if (((uiOCapability & uiOFlags) == uiOFlags) &&
-						((uiOCapability & SND_SEQ_PORT_CAP_NO_EXPORT) == 0)) {
-						QString sOPortName
-							= snd_seq_port_info_get_name(pOPortInfo);
-						if (sOPortName == pOPlug->plugName()) {
-							int iOPort = snd_seq_port_info_get_port(pOPortInfo);
-							// Now, look for subscribers of his port...
-							snd_seq_query_subscribe_set_type(pAlsaSubs,	SND_SEQ_QUERY_SUBS_READ);
-							snd_seq_query_subscribe_set_index(pAlsaSubs, 0);
-							seq_addr.client = iOClient;
-							seq_addr.port   = iOPort;
-							snd_seq_query_subscribe_set_root(pAlsaSubs, &seq_addr);
-							while (snd_seq_query_port_subscribers(pAlsaSeq, pAlsaSubs) >= 0) {
-								seq_addr = *snd_seq_query_subscribe_get_addr(pAlsaSubs);
-								if (snd_seq_get_any_client_info(pAlsaSeq, seq_addr.client, pIClientInfo) == 0) {
-									QString sIClientName = snd_seq_client_info_get_name(pIClientInfo);
-									qjackctlSocketItem *pISocket = m_pISocketList->findSocket(sIClientName);
-									if (pISocket)
-										connectSockets(pOSocket, pISocket);
-								}
-								snd_seq_query_subscribe_set_index(pAlsaSubs, snd_seq_query_subscribe_get_index(pAlsaSubs) + 1);
-							}
-						}
-					}
-				}
-			}
-		}
-	}
-
-#endif	// CONFIG_ALSA_SEQ
-}
-
-
 // Connections snapshot.
 void qjackctlPatchbay::connectionsSnapshot (void)
 {
-	// Take snapshot of client port list.
-	m_pOSocketList->clientPortsSnapshot();
-	m_pISocketList->clientPortsSnapshot();
-
-	// Then, starting from output sockets, try to grab the connections...
-	QListIterator<qjackctlSocketItem *> osocket(m_pOSocketList->sockets());
-	while (osocket.hasNext()) {
-		qjackctlSocketItem *pOSocket = osocket.next();
-		// For each output plug item...
-		QListIterator<qjackctlPlugItem *> oplug(pOSocket->plugs());
-		while (oplug.hasNext()) {
-			qjackctlPlugItem *pOPlug = oplug.next();
-			// Check for socket type...
-			switch (pOSocket->socketType()) {
-			case QJACKCTL_SOCKETTYPE_JACK_AUDIO:
-			case QJACKCTL_SOCKETTYPE_JACK_MIDI:
-				// Get current JACK port connections...
-				socketPlugJackSnapshot(pOSocket, pOPlug);
-				break;
-			case QJACKCTL_SOCKETTYPE_ALSA_MIDI:
-				// Get current MIDI port connections...
-				socketPlugAlsaSnapshot(pOSocket, pOPlug);
-				break;
-			}
-		}
-	}
-
-	// Surely it is kind of tainted.
-	m_pPatchbayView->setDirty(true);
+	qjackctlPatchbayRack rack;
+	rack.connectJackSnapshot(jackClient());
+	rack.connectAlsaSnapshot(alsaSeq());
+	loadRack(&rack);
 }
 
 
