@@ -1,7 +1,7 @@
 // qjackctlPatchbay.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2008, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -177,7 +177,7 @@ public:
 	void removeSocket(qjackctlSocketItem *pSocket);
 
 	// Socket finder.
-	qjackctlSocketItem *findSocket(const QString& sSocketName);
+	qjackctlSocketItem *findSocket(const QString& sSocketName, int iSocketType);
 
 	// List view accessor.
 	qjackctlSocketListView *listView() const;
@@ -199,9 +199,6 @@ public:
 	// Socket list cleaner.
 	void clear();
 
-	// Client:port snapshot.
-	void clientPortsSnapshot();
-
 	// Socket list accessor.
 	QList<qjackctlSocketItem *>& sockets();
 
@@ -222,12 +219,6 @@ public slots:
 	bool moveUpSocketItem();
 	bool moveDownSocketItem();
 
-protected:
-
-	// Specific client:port connections snapshot.
-	void clientJackSnapshot(int iSocketType);
-	void clientAlsaSnapshot(int iSocketType);
-
 private:
 
 	// Merge two pixmaps with union of respective masks.
@@ -485,12 +476,6 @@ private:
 	void disconnectSockets(qjackctlSocketItem *pOSocket,
 		qjackctlSocketItem *pISocket);
 
-	// Output socket-plug connection snapshot subroutines.
-	void socketPlugJackSnapshot(qjackctlSocketItem *pOSocket,
-		qjackctlPlugItem *pOPlug);
-	void socketPlugAlsaSnapshot(qjackctlSocketItem *pOSocket,
-		qjackctlPlugItem *pOPlug);
-
 	// Instance variables.
 	qjackctlPatchbayView *m_pPatchbayView;
 	qjackctlSocketList *m_pOSocketList;
