@@ -80,6 +80,7 @@ qjackctlSetup::qjackctlSetup (void)
 	sDisplayFont2            = m_settings.value("/DisplayFont2").toString();
 	bDisplayEffect           = m_settings.value("/DisplayEffect", true).toBool();
 	bDisplayBlink            = m_settings.value("/DisplayBlink", true).toBool();
+	iJackClientPortAlias     = m_settings.value("/JackClientPortAlias", 0).toInt();
 	iConnectionsIconSize     = m_settings.value("/ConnectionsIconSize", QJACKCTL_ICON_16X16).toInt();
 	sConnectionsFont         = m_settings.value("/ConnectionsFont").toString();
 	bQueryClose              = m_settings.value("/QueryClose", true).toBool();
@@ -98,6 +99,7 @@ qjackctlSetup::qjackctlSetup (void)
 	bRightButtons            = m_settings.value("/RightButtons", true).toBool();
 	bTransportButtons        = m_settings.value("/TransportButtons", true).toBool();
 	bTextLabels              = m_settings.value("/TextLabels", true).toBool();
+	iBaseFontSize            = m_settings.value("/BaseFontSize", 0).toInt();
 	m_settings.endGroup();
 
 	m_settings.beginGroup("/Defaults");
@@ -170,6 +172,7 @@ qjackctlSetup::~qjackctlSetup (void)
 	m_settings.setValue("/DisplayFont2",            sDisplayFont2);
 	m_settings.setValue("/DisplayEffect",           bDisplayEffect);
 	m_settings.setValue("/DisplayBlink",            bDisplayBlink);
+	m_settings.setValue("/JackClientPortAlias",     iJackClientPortAlias);
 	m_settings.setValue("/ConnectionsIconSize",     iConnectionsIconSize);
 	m_settings.setValue("/ConnectionsFont",         sConnectionsFont);
 	m_settings.setValue("/QueryClose",              bQueryClose);
@@ -188,6 +191,7 @@ qjackctlSetup::~qjackctlSetup (void)
 	m_settings.setValue("/RightButtons",            bRightButtons);
 	m_settings.setValue("/TransportButtons",        bTransportButtons);
 	m_settings.setValue("/TextLabels",              bTextLabels);
+	m_settings.setValue("/BaseFontSize",            iBaseFontSize);
 	m_settings.endGroup();
 
 	m_settings.beginGroup("/Defaults");
