@@ -139,6 +139,7 @@ public:
 	QString sDisplayFont2;
 	bool    bDisplayEffect;
 	bool    bDisplayBlink;
+	int     iJackClientPortAlias;
 	int     iConnectionsIconSize;
 	QString sConnectionsFont;
 	bool    bQueryClose;
@@ -157,6 +158,7 @@ public:
 	bool    bRightButtons;
 	bool    bTransportButtons;
 	bool    bTextLabels;
+	int     iBaseFontSize;
 
 	// Defaults...
 	QString sPatchbayPath;
