@@ -357,6 +357,9 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.AliasesEditingCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
+	QObject::connect(m_ui.JackClientPortAliasComboBox,
+		SIGNAL(activated(int)),
+		SLOT(optionsChanged()));
 
 	QObject::connect(m_ui.StartJackCheckBox,
 		SIGNAL(stateChanged(int)),
@@ -403,6 +406,9 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.TextLabelsCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
+	QObject::connect(m_ui.BaseFontSizeComboBox,
+		SIGNAL(editTextChanged(const QString&)),
+		SLOT(optionsChanged()));
 
 	QObject::connect(m_ui.OkPushButton,
 		SIGNAL(clicked()),
@@ -510,7 +516,7 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	const QString sSansSerif = "Sans Serif";
 	QFont font;
 	QPalette pal;
-	
+
 	if (m_pSetup->sDisplayFont1.isEmpty()
 		|| !font.fromString(m_pSetup->sDisplayFont1))
 		font = QFont(sSansSerif, 12, QFont::Bold);
@@ -529,7 +535,7 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 		|| !font.fromString(m_pSetup->sMessagesFont))
 		font = QFont("Monospace", 8);
 	pal = m_ui.MessagesFontTextLabel->palette();
-	pal.setColor(QPalette::Background, Qt::white);
+	pal.setColor(QPalette::Background, pal.base().color());
 	m_ui.MessagesFontTextLabel->setPalette(pal);
 	m_ui.MessagesFontTextLabel->setFont(font);
 	m_ui.MessagesFontTextLabel->setText(
@@ -539,7 +545,7 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 		|| !font.fromString(m_pSetup->sConnectionsFont))
 		font = QFont(sSansSerif, 10);
 	pal = m_ui.ConnectionsFontTextLabel->palette();
-	pal.setColor(QPalette::Background, Qt::white);
+	pal.setColor(QPalette::Background, pal.base().color());
 	m_ui.ConnectionsFontTextLabel->setPalette(pal);
 	m_ui.ConnectionsFontTextLabel->setFont(font);
 	m_ui.ConnectionsFontTextLabel->setText(
@@ -553,6 +559,9 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	// Connections view icon size.
 	m_ui.ConnectionsIconSizeComboBox->setCurrentIndex(
 		m_pSetup->iConnectionsIconSize);
+	// and this JACK speciality...
+	m_ui.JackClientPortAliasComboBox->setCurrentIndex(
+		m_pSetup->iJackClientPortAlias);
 
 	// Messages limit option.
 	m_ui.MessagesLimitCheckBox->setChecked(m_pSetup->bMessagesLimit);
@@ -578,6 +587,10 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	m_ui.RightButtonsCheckBox->setChecked(!m_pSetup->bRightButtons);
 	m_ui.TransportButtonsCheckBox->setChecked(!m_pSetup->bTransportButtons);
 	m_ui.TextLabelsCheckBox->setChecked(!m_pSetup->bTextLabels);
+	if (m_pSetup->iBaseFontSize > 0)
+		m_ui.BaseFontSizeComboBox->setEditText(QString::number(m_pSetup->iBaseFontSize));
+	else
+		m_ui.BaseFontSizeComboBox->setCurrentIndex(0);
 
 #ifndef CONFIG_SYSTEM_TRAY
 	m_ui.SystemTrayCheckBox->setChecked(false);
@@ -857,6 +870,7 @@ void qjackctlSetupForm::changeDriverAudio ( const QString& sDriver, int iAudio )
 	bool bNet        = (sDriver == "net");
 	bool bInEnabled  = false;
 	bool bOutEnabled = false;
+	bool bEnabled;
 
 	switch (iAudio) {
 	case QJACKCTL_DUPLEX:
@@ -871,29 +885,37 @@ void qjackctlSetupForm::changeDriverAudio ( const QString& sDriver, int iAudio )
 		break;
 	}
 
-	m_ui.InDeviceTextLabel->setEnabled(bInEnabled && (bAlsa || bSun || bOss));
-	m_ui.InDeviceComboBox->setEnabled(bInEnabled && (bAlsa || bSun || bOss));
-	m_ui.InDeviceToolButton->setEnabled(bInEnabled && (bAlsa || bSun || bOss));
-	m_ui.OutDeviceTextLabel->setEnabled(bOutEnabled && (bAlsa || bSun || bOss));
-	m_ui.OutDeviceComboBox->setEnabled(bOutEnabled && (bAlsa || bSun || bOss));
-	m_ui.OutDeviceToolButton->setEnabled(bOutEnabled && (bAlsa || bSun || bOss));
+	bEnabled = (bInEnabled && (bAlsa || bSun || bOss));
+	m_ui.InDeviceTextLabel->setEnabled(bEnabled);
+	m_ui.InDeviceComboBox->setEnabled(bEnabled);
+	m_ui.InDeviceToolButton->setEnabled(bEnabled);
+	if (!bEnabled)
+		setComboBoxCurrentText(m_ui.InDeviceComboBox, m_pSetup->sDefPresetName);
+
+	bEnabled = (bOutEnabled && (bAlsa || bSun || bOss));
+	m_ui.OutDeviceTextLabel->setEnabled(bEnabled);
+	m_ui.OutDeviceComboBox->setEnabled(bEnabled);
+	m_ui.OutDeviceToolButton->setEnabled(bEnabled);
+	if (!bEnabled)
+		setComboBoxCurrentText(m_ui.OutDeviceComboBox, m_pSetup->sDefPresetName);
 
 	m_ui.InChannelsTextLabel->setEnabled(bInEnabled
 		|| ((bAlsa || bFirewire) && iAudio != QJACKCTL_PLAYBACK));
 	m_ui.InChannelsSpinBox->setEnabled(bInEnabled
 		|| ((bAlsa || bFirewire) && iAudio != QJACKCTL_PLAYBACK));
+
 	m_ui.OutChannelsTextLabel->setEnabled(bOutEnabled
 		|| ((bAlsa || bFirewire) && iAudio != QJACKCTL_CAPTURE));
 	m_ui.OutChannelsSpinBox->setEnabled(bOutEnabled
 		|| ((bAlsa || bFirewire) && iAudio != QJACKCTL_CAPTURE));
 
-	m_ui.InLatencyTextLabel->setEnabled(bInEnabled && !bNet
+	m_ui.InLatencyTextLabel->setEnabled((bInEnabled && !bNet)
 		|| ((bAlsa || bFreebob) && iAudio != QJACKCTL_PLAYBACK));
-	m_ui.InLatencySpinBox->setEnabled(bInEnabled && !bNet
+	m_ui.InLatencySpinBox->setEnabled((bInEnabled && !bNet)
 		|| ((bAlsa || bFreebob) && iAudio != QJACKCTL_PLAYBACK));
-	m_ui.OutLatencyTextLabel->setEnabled(bOutEnabled && !bNet
+	m_ui.OutLatencyTextLabel->setEnabled((bOutEnabled && !bNet)
 		|| ((bAlsa || bFreebob) && iAudio != QJACKCTL_CAPTURE));
-	m_ui.OutLatencySpinBox->setEnabled(bOutEnabled && !bNet
+	m_ui.OutLatencySpinBox->setEnabled((bOutEnabled && !bNet)
 		|| ((bAlsa || bFreebob) && iAudio != QJACKCTL_CAPTURE));
 
 	computeLatency();
@@ -968,9 +990,13 @@ void qjackctlSetupForm::changeDriverUpdate ( const QString& sDriver, bool bUpdat
 		bEnabled = (sInDevice.isEmpty()  || sInDevice  == m_pSetup->sDefPresetName ||
 					sOutDevice.isEmpty() || sOutDevice == m_pSetup->sDefPresetName);
 	}
-	m_ui.InterfaceTextLabel->setEnabled(bEnabled || bCoreaudio || bFreebob || bFirewire);
-	m_ui.InterfaceComboBox->setEnabled(bEnabled || bCoreaudio || bFreebob || bFirewire);
+
+	bool bInterface = (bEnabled || bCoreaudio || bFreebob || bFirewire);
+	m_ui.InterfaceTextLabel->setEnabled(bInterface);
+	m_ui.InterfaceComboBox->setEnabled(bInterface);
 	m_ui.InterfaceToolButton->setEnabled(bEnabled || bCoreaudio);
+	if (!bInterface)
+		setComboBoxCurrentText(m_ui.InterfaceComboBox, m_pSetup->sDefPresetName);
 
 	m_ui.DitherTextLabel->setEnabled(bAlsa || bPortaudio);
 	m_ui.DitherComboBox->setEnabled(bAlsa || bPortaudio);
@@ -1170,6 +1196,7 @@ void qjackctlSetupForm::deviceMenu( QLineEdit *pLineEdit,
 		snd_pcm_info_t *pcminfo;
 		snd_ctl_card_info_alloca(&info);
 		snd_pcm_info_alloca(&pcminfo);
+		bool bCapture, bPlayback;
 		int iCard = -1;
 		while (snd_card_next(&iCard) >= 0 && iCard >= 0) {
 			sName = "hw:" + QString::number(iCard);
@@ -1185,13 +1212,28 @@ void qjackctlSetupForm::deviceMenu( QLineEdit *pLineEdit,
 				int iDevice = -1;
 				while (snd_ctl_pcm_next_device(handle, &iDevice) >= 0
 					&& iDevice >= 0) {
-					snd_pcm_info_set_device(pcminfo, iDevice);
-					snd_pcm_info_set_subdevice(pcminfo, 0);
-					snd_pcm_info_set_stream(pcminfo,
-						iAudio == QJACKCTL_CAPTURE ?
-							SND_PCM_STREAM_CAPTURE :
-							SND_PCM_STREAM_PLAYBACK);
-					if (snd_ctl_pcm_info(handle, pcminfo) >= 0) {
+					// Capture devices..
+					bCapture = false;
+					if (iAudio == QJACKCTL_CAPTURE ||
+						iAudio == QJACKCTL_DUPLEX) {
+						snd_pcm_info_set_device(pcminfo, iDevice);
+						snd_pcm_info_set_subdevice(pcminfo, 0);
+						snd_pcm_info_set_stream(pcminfo, SND_PCM_STREAM_CAPTURE);
+						bCapture = (snd_ctl_pcm_info(handle, pcminfo) >= 0);
+					}
+					// Playback devices..
+					bPlayback = false;
+					if (iAudio == QJACKCTL_PLAYBACK ||
+						iAudio == QJACKCTL_DUPLEX) {
+						snd_pcm_info_set_device(pcminfo, iDevice);
+						snd_pcm_info_set_subdevice(pcminfo, 0);
+						snd_pcm_info_set_stream(pcminfo, SND_PCM_STREAM_PLAYBACK);
+						bPlayback = (snd_ctl_pcm_info(handle, pcminfo) >= 0);
+					}
+					// List iif compliant with the audio mode criteria...
+					if ((iAudio == QJACKCTL_CAPTURE && bCapture && !bPlayback) ||
+						(iAudio == QJACKCTL_PLAYBACK && !bCapture && bPlayback) ||
+						(iAudio == QJACKCTL_DUPLEX && bCapture && bPlayback)) {
 						sSubName = sName + ',' + QString::number(iDevice);
 						sText  = sSubName + '\t';
 						sText += snd_pcm_info_get_name(pcminfo);
@@ -1681,6 +1723,7 @@ void qjackctlSetupForm::accept (void)
 		m_pSetup->sDisplayFont2            = m_ui.DisplayFont2TextLabel->font().toString();
 		m_pSetup->bDisplayEffect           = m_ui.DisplayEffectCheckBox->isChecked();
 		m_pSetup->bDisplayBlink            = m_ui.DisplayBlinkCheckBox->isChecked();
+		m_pSetup->iJackClientPortAlias     = m_ui.JackClientPortAliasComboBox->currentIndex();
 		m_pSetup->iConnectionsIconSize     = m_ui.ConnectionsIconSizeComboBox->currentIndex();
 		m_pSetup->sConnectionsFont         = m_ui.ConnectionsFontTextLabel->font().toString();
 		m_pSetup->bStartJack               = m_ui.StartJackCheckBox->isChecked();
@@ -1700,6 +1743,7 @@ void qjackctlSetupForm::accept (void)
 		m_pSetup->bRightButtons            = !m_ui.RightButtonsCheckBox->isChecked();
 		m_pSetup->bTransportButtons        = !m_ui.TransportButtonsCheckBox->isChecked();
 		m_pSetup->bTextLabels              = !m_ui.TextLabelsCheckBox->isChecked();
+		m_pSetup->iBaseFontSize            = m_ui.BaseFontSizeComboBox->currentText().toInt();
 	}
 
 	// Save combobox history...
