@@ -25,7 +25,7 @@
 #include <QBitmap>
 #include <QPainter>
 
-#if QT_VERSION < 0x040200
+#ifndef QJACKCTL_QT4_SYSTEM_TRAY
 
 #include <QMouseEvent>
 #include <QPaintEvent>
@@ -50,7 +50,7 @@
 //----------------------------------------------------------------------------
 // qjackctlSystemTray -- Custom system tray widget.
 
-#if QT_VERSION >= 0x040200
+#ifdef QJACKCTL_QT4_SYSTEM_TRAY
 
 // Constructor.
 qjackctlSystemTray::qjackctlSystemTray ( QWidget *pParent )
@@ -89,8 +89,10 @@ void qjackctlSystemTray::activated ( QSystemTrayIcon::ActivationReason reason )
 		break;
 	case QSystemTrayIcon::Trigger:
 		emit clicked();
-		// Fall trhu...
+		break;
 	case QSystemTrayIcon::MiddleClick:
+		emit middleClicked();
+		break;
 	case QSystemTrayIcon::DoubleClick:
 	case QSystemTrayIcon::Unknown:
 	default:
@@ -103,12 +105,16 @@ void qjackctlSystemTray::activated ( QSystemTrayIcon::ActivationReason reason )
 // Constructor.
 qjackctlSystemTray::qjackctlSystemTray ( QWidget *pParent )
 	: QWidget(pParent, Qt::Window
+#if QT_VERSION >= 0x040200
 		| Qt::CustomizeWindowHint
+#endif
 		| Qt::X11BypassWindowManagerHint
 		| Qt::FramelessWindowHint
 		| Qt::WindowStaysOnTopHint)
 {
+#if QT_VERSION >= 0x040200
 	QWidget::setAttribute(Qt::WA_AlwaysShowToolTips);
+#endif
 //	QWidget::setAttribute(Qt::WA_NoSystemBackground);
 
 //	QWidget::setBackgroundRole(QPalette::NoRole);
@@ -185,7 +191,7 @@ qjackctlSystemTray::~qjackctlSystemTray (void)
 void qjackctlSystemTray::updatePixmap (void)
 {
 	// Renitialize icon as fit...
-#if QT_VERSION >= 0x040200
+#ifdef QJACKCTL_QT4_SYSTEM_TRAY
 	m_pixmap = m_icon.pixmap(22, 22);
 #else
 	m_pixmap = QWidget::windowIcon().pixmap(QWidget::size());
@@ -199,7 +205,7 @@ void qjackctlSystemTray::updatePixmap (void)
 		QPainter(&m_pixmap).drawPixmap(0, 0, m_pixmapOverlay);
 	}
 
-#if QT_VERSION >= 0x040200
+#ifdef QJACKCTL_QT4_SYSTEM_TRAY
 
 	if (m_background != Qt::transparent) {
 		QPixmap pixmap(m_pixmap);
@@ -239,7 +245,7 @@ void qjackctlSystemTray::setBackground ( const QColor& background )
 	// Set background color, now.
 	m_background = background;
 
-#if QT_VERSION < 0x040200
+#ifndef QJACKCTL_QT4_SYSTEM_TRAY
 
 	QPalette pal(QWidget::palette());
 	pal.setColor(QWidget::backgroundRole(), m_background);
@@ -270,7 +276,7 @@ const QPixmap& qjackctlSystemTray::pixmapOverlay (void) const
 }
 
 
-#if QT_VERSION < 0x040200
+#ifndef QJACKCTL_QT4_SYSTEM_TRAY
 
 // Self-drawable methods.
 void qjackctlSystemTray::paintEvent ( QPaintEvent * )
@@ -297,6 +303,10 @@ void qjackctlSystemTray::mousePressEvent ( QMouseEvent *pMouseEvent )
 		emit clicked();
 		break;
 
+	case Qt::MidButton:
+		emit middleClicked();
+		break;
+
 	case Qt::RightButton:
 		// Just signal we're on to context menu.
 		emit contextMenuRequested(pMouseEvent->globalPos());
